@@ -10,10 +10,12 @@ clasicLastplusNode = new Image(16,16);
 clasicLastplusNode.src='/style/Crystal/16/html-menu-treeview/clasicLastplusNode.gif';
 folderManClosed = new Image(16,16);
 folderManClosed.src='/style/Crystal/16/html-menu-treeview/folderManClosed.gif';
-folderGray = new Image(16,16);
-folderGray.src='/style/Crystal/16/html-menu-treeview/folderGray.gif';
-folderGreen = new Image(16,16);
-folderGreen.src='/style/Crystal/16/html-menu-treeview/folderGreen.gif';
+folderGrayClosed = new Image(16,16);
+folderGrayClosed.src='/style/Crystal/16/html-menu-treeview/folderGrayClosed.gif';
+folderGreenClosed = new Image(16,16);
+folderGreenClosed.src='/style/Crystal/16/html-menu-treeview/folderGreenClosed.gif';
+folderRedClosed = new Image(16,16);
+folderRedClosed.src='/style/Crystal/16/html-menu-treeview/folderRedClosed.gif';
 folderViolet = new Image(16,16);
 folderViolet.src='/style/Crystal/16/html-menu-treeview/folderViolet.gif';
 folderYellowClosed = new Image(16,16);
@@ -56,10 +58,12 @@ clasicLastplusNode22 = new Image(22,22);
 clasicLastplusNode22.src='/style/Crystal/22/html-menu-treeview/clasicLastplusNode.gif';
 folderManClosed22 = new Image(22,22);
 folderManClosed22.src='/style/Crystal/22/html-menu-treeview/folderManClosed.gif';
-folderGray22 = new Image(22,22);
-folderGray22.src='/style/Crystal/22/html-menu-treeview/folderGray.gif';
-folderGreen22 = new Image(22,22);
-folderGreen22.src='/style/Crystal/22/html-menu-treeview/folderGreen.gif';
+folderGrayClosed22 = new Image(22,22);
+folderGrayClosed22.src='/style/Crystal/22/html-menu-treeview/folderGrayClosed.gif';
+folderGreenClosed22 = new Image(22,22);
+folderGreenClosed22.src='/style/Crystal/22/html-menu-treeview/folderGreenClosed.gif';
+folderRedClosed22 = new Image(22,22);
+folderRedClosed22.src='/style/Crystal/22/html-menu-treeview/folderRedClosed22.gif';
 folderViolet22 = new Image(22,22);
 folderViolet22.src='/style/Crystal/22/html-menu-treeview/folderViolet.gif';
 folderYellowClosed22 = new Image(22,22);
@@ -102,10 +106,12 @@ clasicLastplusNode32 = new Image(32,32);
 clasicLastplusNode32.src='/style/Crystal/32/html-menu-treeview/clasicLastplusNode.gif';
 folderManClosed32 = new Image(32,32);
 folderManClosed32.src='/style/Crystal/32/html-menu-treeview/folderManClosed.gif';
-folderGray32 = new Image(32,32);
-folderGray32.src='/style/Crystal/32/html-menu-treeview/folderGray.gif';
-folderGreen32 = new Image(32,32);
-folderGreen32.src='/style/Crystal/32/html-menu-treeview/folderGreen.gif';
+folderGrayClosed32 = new Image(32,32);
+folderGrayClosed32.src='/style/Crystal/32/html-menu-treeview/folderGrayClosed.gif';
+folderGreenClosed32 = new Image(32,32);
+folderGreenClosed32.src='/style/Crystal/32/html-menu-treeview/folderGreenClosed.gif';
+folderRedClosed32 = new Image(32,32);
+folderRedClosed32.src='/style/Crystal/32/html-menu-treeview/folderRedClosed32.gif';
 folderViolet32 = new Image(32,32);
 folderViolet32.src='/style/Crystal/32/html-menu-treeview/folderViolet.gif';
 folderYellowClosed32 = new Image(32,32);
@@ -148,10 +154,12 @@ clasicLastplusNode48 = new Image(48,48);
 clasicLastplusNode48.src='/style/Crystal/48/html-menu-treeview/clasicLastplusNode.gif';
 folderManClosed48 = new Image(48,48);
 folderManClosed48.src='/style/Crystal/48/html-menu-treeview/folderManClosed.gif';
-folderGray48 = new Image(48,48);
-folderGray48.src='/style/Crystal/48/html-menu-treeview/folderGray.gif';
-folderGreen48 = new Image(48,48);
-folderGreen48.src='/style/Crystal/48/html-menu-treeview/folderGreen.gif';
+folderGrayClosed48 = new Image(48,48);
+folderGrayClosed48.src='/style/Crystal/48/html-menu-treeview/folderGrayClosed.gif';
+folderGreenClosed48 = new Image(48,48);
+folderGreenClosed48.src='/style/Crystal/48/html-menu-treeview/folderGreenClosed.gif';
+folderRedClosed48 = new Image(48,48);
+folderRedClosed48.src='/style/Crystal/48/html-menu-treeview/folderRedClosed48.gif';
 folderViolet48 = new Image(48,48);
 folderViolet48.src='/style/Crystal/48/html-menu-treeview/folderViolet.gif';
 folderYellowClosed48 = new Image(48,48);
@@ -194,10 +202,12 @@ clasicLastplusNode64 = new Image(64,64);
 clasicLastplusNode64.src='/style/Crystal/64/html-menu-treeview/clasicLastplusNode.gif';
 folderManClosed64 = new Image(64,64);
 folderManClosed64.src='/style/Crystal/64/html-menu-treeview/folderManClosed.gif';
-folderGray64 = new Image(64,64);
-folderGray64.src='/style/Crystal/64/html-menu-treeview/folderGray.gif';
-folderGreen64 = new Image(64,64);
-folderGreen64.src='/style/Crystal/64/html-menu-treeview/folderGreen.gif';
+folderGrayClosed64 = new Image(64,64);
+folderGrayClosed64.src='/style/Crystal/64/html-menu-treeview/folderGrayClosed.gif';
+folderGreenClosed64 = new Image(64,64);
+folderGreenClosed64.src='/style/Crystal/64/html-menu-treeview/folderGreenClosed.gif';
+folderRedClosed64 = new Image(64,64);
+folderRedClosed64.src='/style/Crystal/64/html-menu-treeview/folderRedClosed64.gif';
 folderViolet64 = new Image(64,64);
 folderViolet64.src='/style/Crystal/64/html-menu-treeview/folderViolet.gif';
 folderYellowClosed64 = new Image(64,64);
@@ -240,10 +250,12 @@ clasicLastplusNode128 = new Image(128,128);
 clasicLastplusNode128.src='/style/Crystal/128/html-menu-treeview/clasicLastplusNode.gif';
 folderManClosed128 = new Image(128,128);
 folderManClosed128.src='/style/Crystal/128/html-menu-treeview/folderManClosed.gif';
-folderGray128 = new Image(128,128);
-folderGray128.src='/style/Crystal/128/html-menu-treeview/folderGray.gif';
-folderGreen128 = new Image(128,128);
-folderGreen128.src='/style/Crystal/128/html-menu-treeview/folderGreen.gif';
+folderGrayClosed128 = new Image(128,128);
+folderGrayClosed128.src='/style/Crystal/128/html-menu-treeview/folderGrayClosed.gif';
+folderGreenClosed128 = new Image(128,128);
+folderGreenClosed128.src='/style/Crystal/128/html-menu-treeview/folderGreenClosed.gif';
+folderRedClosed128 = new Image(128,128);
+folderRedClosed128.src='/style/Crystal/128/html-menu-treeview/folderRedClosed128.gif';
 folderViolet128 = new Image(128,128);
 folderViolet128.src='/style/Crystal/128/html-menu-treeview/folderViolet.gif';
 folderYellowClosed128 = new Image(128,128);
